==> xjc-gradle-plugin-1.6.0-sources.jar: com/github/bjornvester/xjc/XjcExtension.kt <==
package com.github.bjornvester.xjc

import org.gradle.api.NamedDomainObjectContainer
import org.gradle.api.file.FileCollection
import org.gradle.api.file.ProjectLayout
import org.gradle.api.model.ObjectFactory
import javax.inject.Inject

open class XjcExtension @Inject constructor(objects: ObjectFactory, layout: ProjectLayout) : XjcExtensionGroup {
    val xjcVersion = objects.property(String::class.java).convention("2.3.3")

    override val name = "Defaults"
    override val xsdDir = objects.directoryProperty().convention(layout.projectDirectory.dir("src/main/resources"))
    override var xsdFiles: FileCollection = xsdDir.asFileTree.matching { include("**/*.xsd") } // TODO: Once a ConfigurableFileCollection, change to: objects.fileCollection().from(...)
    override val outputJavaDir = objects.directoryProperty().convention(layout.buildDirectory.dir("generated/sources/xjc/java"))
    override val outputResourcesDir = objects.directoryProperty().convention(layout.buildDirectory.dir("generated/sources/xjc/resources"))
    override val defaultPackage = objects.property(String::class.java)
    override val generateEpisode = objects.property(Boolean::class.java).convention(false)
    override var bindingFiles: FileCollection = objects.fileCollection()
    override val options = objects.listProperty(String::class.java)
    override val markGenerated = objects.property(Boolean::class.java).convention(false)

    val groups: NamedDomainObjectContainer<XjcExtensionGroup> = objects.domainObjectContainer(XjcExtensionGroup::class.java)

    init {
        groups.configureEach {
            xsdDir.convention(this@XjcExtension.xsdDir)
            xsdFiles = objects.fileCollection() // Once this field is "val", change to a convention
            outputJavaDir.convention(layout.buildDirectory.dir("generated/sources/xjc-$name/java"))
            outputResourcesDir.convention(layout.buildDirectory.dir("generated/sources/xjc-$name/resources"))
            xjcVersion.convention(this@XjcExtension.xjcVersion)
            defaultPackage.convention(this@XjcExtension.defaultPackage)
            generateEpisode.convention(this@XjcExtension.generateEpisode)
            bindingFiles = objects.fileCollection() // Once this field is "val", change to a convention
            options.convention(this@XjcExtension.options)
            markGenerated.convention(this@XjcExtension.markGenerated)
        }
    }
}

==> xjc-gradle-plugin-1.8.2-sources.jar: com/github/bjornvester/xjc/XjcExtension.kt <==
package com.github.bjornvester.xjc

import org.gradle.api.NamedDomainObjectContainer
import org.gradle.api.file.ProjectLayout
import org.gradle.api.model.ObjectFactory
import javax.inject.Inject

open class XjcExtension @Inject constructor(objects: ObjectFactory, layout: ProjectLayout) : XjcExtensionGroup {
    val useJakarta = objects.property(Boolean::class.java).convention(true)
    val xjcVersion = objects.property(String::class.java).convention(useJakarta.map { if (it) "3.0.2" else "2.3.8" })
    val addCompilationDependencies = objects.property(Boolean::class.java).convention(true)

    override val name = "Defaults"
    final override val xsdDir = objects.directoryProperty().convention(layout.projectDirectory.dir("src/main/resources"))
    override val includes = objects.listProperty(String::class.java).convention(listOf("**/*.xsd"))
    override val excludes = objects.listProperty(String::class.java)
    override val outputJavaDir = objects.directoryProperty().convention(layout.buildDirectory.dir("generated/sources/xjc/java"))
    override val outputResourcesDir = objects.directoryProperty().convention(layout.buildDirectory.dir("generated/sources/xjc/resources"))
    override val defaultPackage = objects.property(String::class.java)
    override val generateEpisode = objects.property(Boolean::class.java).convention(false)
    override val bindingFiles = objects.fileCollection().from(xsdDir.asFileTree.matching { include("**/*.xjb") })
    override val options = objects.listProperty(String::class.java)
    override val markGenerated = objects.property(Boolean::class.java).convention(false)

    val groups: NamedDomainObjectContainer<XjcExtensionGroup> = objects.domainObjectContainer(XjcExtensionGroup::class.java)

    init {
        groups.configureEach {
            xsdDir.convention(this@XjcExtension.xsdDir)
            includes.convention(this@XjcExtension.includes)
            excludes.convention(this@XjcExtension.excludes)
            outputJavaDir.convention(layout.buildDirectory.dir("generated/sources/xjc-$name/java"))
            outputResourcesDir.convention(layout.buildDirectory.dir("generated/sources/xjc-$name/resources"))
            defaultPackage.convention(this@XjcExtension.defaultPackage)
            generateEpisode.convention(this@XjcExtension.generateEpisode)
            bindingFiles.setFrom(this@XjcExtension.bindingFiles)
            options.convention(this@XjcExtension.options)
            markGenerated.convention(this@XjcExtension.markGenerated)
        }
    }
}
